┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/kitemviews/kitemlistwidget.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2011-10-23 21:30:40 +0200
committerPeter Penz <[email protected]>2011-10-23 21:32:35 +0200
commit517ebd721e12e3a4a3430ac3cba8ce99b33c5b0e (patch)
treecfc30b7ac02f13fdefa1d53e6c8516a27c90e4ca /src/kitemviews/kitemlistwidget.h
parent930b3070ffcf45fae26ad0edb0125d1467f7b4a6 (diff)
Improve group-header layout
- Apply a dynamic width - Use a height that depends on the style - Cleanup some interfaces and replace xxxBoundingRect() by xxxRect()
Diffstat (limited to 'src/kitemviews/kitemlistwidget.h')
-rw-r--r--src/kitemviews/kitemlistwidget.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/kitemviews/kitemlistwidget.h b/src/kitemviews/kitemlistwidget.h
index eae4c39da..2df19a610 100644
--- a/src/kitemviews/kitemlistwidget.h
+++ b/src/kitemviews/kitemlistwidget.h
@@ -53,7 +53,7 @@ public:
QHash<QByteArray, QVariant> data() const;
/**
- * Draws the hover-bounding-rectangle if the item is hovered. Overwrite this method
+ * Draws the hover-rectangle if the item is hovered. Overwrite this method
* to show the data of the custom model provided by KItemListWidget::data().
* @reimp
*/
@@ -81,22 +81,22 @@ public:
bool alternatingBackgroundColors() const;
/**
* @return True if \a point is inside KItemListWidget::hoverBoundingRect(),
* KItemListWidget::textBoundingRect(), KItemListWidget::selectionToggleRect()
* or KItemListWidget::expansionToggleRect().
* @reimp
*/
virtual bool contains(const QPointF& point) const;
/**
- * @return Bounding rectangle for the area that shows the icon.
+ * @return Rectangle for the area that shows the icon.
*/
- virtual QRectF iconBoundingRect() const = 0;
+ virtual QRectF iconRect() const = 0;
/**
- * @return Bounding rectangle for the area that contains the text-properties.
+ * @return Rectangle for the area that contains the text-properties.
*/
- virtual QRectF textBoundingRect() const = 0;
+ virtual QRectF textRect() const = 0;
/**
* @return Rectangle for the selection-toggle that is used to select or deselect an item.
@@ -81,22 +81,22 @@ public:
bool alternatingBackgroundColors() const;
/**
- * @return True if \a point is inside KItemListWidget::hoverBoundingRect(),
- * KItemListWidget::textBoundingRect(), KItemListWidget::selectionToggleRect()
+ * @return True if \a point is inside KItemListWidget::hoverRect(),
+ * KItemListWidget::textRect(), KItemListWidget::selectionToggleRect()
* or KItemListWidget::expansionToggleRect().
* @reimp